<?php
/**
*
* Memberlist only Admin extension for the phpBB Forum Software package.
*
* @copyright Kirk http://reyno41.bplaced.net/phpbb
* @license GNU General Public License, version 2 (GPL-2.0)
*
*/

namespace kirk\memberlist_only_admin\event;

/**
* @ignore
*/
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{
	/** @var \phpbb\auth\auth */
	protected $auth;

	/** @var \phpbb\template\template */
	protected $template;

	/* @var \phpbb\user */
	protected $user;

	/**
		* Constructor
		*
		* @param \phpbb\auth\auth						auth			Authentication object
		* @param \phpbb\template\template				$template		Template object
		* @param \phpbb\user							$user			User Object
		* @access public
		*/

		public function __construct(\phpbb\auth\auth $auth, \phpbb\template\template $template, \phpbb\user $user)
	{
		$this->auth			= $auth;
		$this->template		= $template;
		$this->user			= $user;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.user_setup'							=> 'load_language_on_setup',
			'core.memberlist_memberrow_before'			=> 'show_memberlist_only_admin',
			'core.page_header_after'					=> 'hide_memberlist_link',
		);
	}

	/**
	* Load language during user setup
	*
	* @param object $event The event object
	* @return null
	*/
	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
				'ext_name'		=> 'kirk/memberlist_only_admin',
				'lang_set'		=> 'common',
			);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function show_memberlist_only_admin($event)
	{
		if (!$this->auth->acl_gets('a_'))
		{
			if ($this->user->data['user_id'] != ANONYMOUS)
			{
				send_status_line(403, 'Forbidden');
				trigger_error('NO_VIEW_MEMBERLIST');
			}
		}
	}

	public function hide_memberlist_link($event)
	{
		$this->template->assign_vars(array(
			'S_DISPLAY_MEMBERLIST'	=> $this->user->data['user_type'] == USER_FOUNDER || $this->auth->acl_get('a_'),
		));
	}
}
